MOSViz: Visualization Tool for Multi-object Spectroscopy
########################################################

.. DANGER::

      Please note that this version of MOSViz is **no longer being actively supported
      or maintained**. The functionality of MOSViz is now available and being actively
      developed as part of `Jdaviz <https://github.com/spacetelescope/jdaviz>`_.

If you must use legacy MOSViz, please try v0.3.1 in Python 3.6. For legacy
MOSViz, see https://pypi.org/project/mosviz/ .

If you would like to fork https://github.com/spacetelescope/mosviz/
and continue developing in your own, we suggest you start from commit
``361aff46e348bd4a85e3efbb1126d56c1019bb49``.
